@@ -261,13 +261,13 @@ check_prior <- function(prior_obj) {
       stop("block_exo must be a vector of indexes or names.")
     } else {
       if (is.character(prior_obj$block_exo)) {
-        if (all(prior_obj$block_exo %in% colnames(obj$Y))) {
-          prior_obj$block_exo <- sapply(prior_obj$block_exo, function(x) colnames(obj$Y) == x)
+        if (all(prior_obj$block_exo %in% colnames(prior_obj$Y))) {
+          prior_obj$block_exo <- which(prior_obj$block_exo %in% colnames(prior_obj$Y))
         }
       }
     }
   } else {
-    prior_obj$supplied_args <- c(prior_obj$supplied_args, "lambda4")
+    prior_obj$supplied_args <- c(prior_obj$supplied_args, "block_exo")
   }
 
 
@@ -711,9 +711,9 @@ summary.mfbvar_prior <- function(object, ...) {
 #' @details
 #' Choosing \code{variance %in% c("iw", "csv")} imposes a symmetric prior on the regression parameters. For this reason, \code{prior = "dl"} can only be used together with \code{variance %in% c("diffuse", "fsv")}.
 #' @references
-#' Ankargren, S., Unosson, M., & Yang, Y. (2019) A Flexible Mixed-Frequency Bayesian Vector Autoregression with a Steady-State Prior. Manuscript.\cr
+#' Ankargren, S., Unosson, M., & Yang, Y. (2019) A Flexible Mixed-Frequency Bayesian Vector Autoregression with a Steady-State Prior. arXiv:1911.09151, \url{https://arxiv.org/abs/1911.09151}.\cr
 #' Ankargren, S., & Jonéus, P. (2019) Simulation Smoothing for Nowcasting with Large Mixed-Frequency VARs. arXiv:1907.01075, \url{http://arxiv.org/abs/1907.01075}.\cr
-#' Ankargren, S., & Jonéus, P. (2019) Estimating Large Mixed-Frequency Bayesian VAR Models. Manuscript.\cr
+#' Ankargren, S., & Jonéus, P. (2019) Estimating Large Mixed-Frequency Bayesian VAR Models. arXiv:1912.02231, \url{https://arxiv.org/abs/1912.02231}.\cr
 #' Kastner, G., & Huber, F. (2018) Sparse Bayesian Vector Autoregressions in Huge Dimensions. arXiv:1704.03239, \url{http://arxiv.org/abs/1704.03239}.\cr
 #' Schorfheide, F., & Song, D. (2015) Real-Time Forecasting With a Mixed-Frequency VAR. \emph{Journal of Business & Economic Statistics}, 33(3), 366--380. \url{http://dx.doi.org/10.1080/07350015.2014.954707}\cr
 
@@ -1520,9 +1520,9 @@ plot.mfbvar_prior <- function(x, nrow_facet = NULL, ...){
 
   if (ss_flag) {
     n_determ <- ncol(x$d)
-    ss_lower  <- x$d %*% t(matrix(qnorm(ss_level[1], x$prior_psi_mean, diag(x$prior_psi_Omega)), ncol = n_determ))
-    ss_median <- x$d %*% t(matrix(qnorm(0.5, x$prior_psi_mean, diag(x$prior_psi_Omega)), ncol = n_determ))
-    ss_upper  <- x$d %*% t(matrix(qnorm(ss_level[2], x$prior_psi_mean, diag(x$prior_psi_Omega)), ncol = n_determ))
+    ss_lower  <- x$d %*% t(matrix(qnorm(ss_level[1], x$prior_psi_mean, sqrt(diag(x$prior_psi_Omega))), ncol = n_determ))
+    ss_median <- x$d %*% t(matrix(qnorm(0.5, x$prior_psi_mean, sqrt(diag(x$prior_psi_Omega))), ncol = n_determ))
+    ss_upper  <- x$d %*% t(matrix(qnorm(ss_level[2], x$prior_psi_mean, sqrt(diag(x$prior_psi_Omega))), ncol = n_determ))
 
     ss <- data.frame(expand.grid(time = as.Date(rownames(x$Y)), variable = names_col), lower = c(ss_lower), median = c(ss_median),
                      upper = c(ss_upper))
